==> haskell-ghc-tcplugins-extra-0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
key: ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: 81f42ca618f9655ae584707d3077fbb5
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
depends:
    base-4.11.1.0 ghc-8.4.3
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-8.4.3=eef2f41901320161f5f168c67278fe14
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-tcplugins-extra-0.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
key: ghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: 805248f89fc9a7b9e16b6200a4c2fb9c
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.6.1/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
depends:
    base-4.12.0.0 ghc-8.6.1
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
